@@ -576,6 +576,27 @@ out:
   return;
 }
 
+static void
+gcm_prefs_make_profile_default_cb (GObject *object,
+                                   GAsyncResult *res,
+                                   gpointer user_data)
+{
+  CdDevice *device = CD_DEVICE (object);
+  gboolean ret = FALSE;
+  GError *error = NULL;
+
+  ret = cd_device_make_profile_default_finish (device,
+                                               res,
+                                               &error);
+  if (!ret)
+    {
+      g_warning ("failed to set default profile on %s: %s",
+                 cd_device_get_id (device),
+                 error->message);
+      g_error_free (error);
+    }
+}
+
 static void
 gcm_prefs_profile_make_default_internal (CcColorPanel *prefs,
                                          GtkTreeModel *model,
@@ -583,8 +604,6 @@ gcm_prefs_profile_make_default_internal (CcColorPanel *prefs,
 {
   CdDevice *device;
   CdProfile *profile;
-  GError *error = NULL;
-  gboolean ret = FALSE;
   CcColorPanelPrivate *priv = prefs->priv;
 
   /* get currentlt selected item */
@@ -596,16 +615,14 @@ gcm_prefs_profile_make_default_internal (CcColorPanel *prefs,
     goto out;
 
   /* just set it default */
-  ret = cd_device_make_profile_default_sync (device,
-                                             profile,
-                                             priv->cancellable,
-                                             &error);
-  if (!ret)
-    {
-      g_warning ("failed to set default profile: %s", error->message);
-      g_error_free (error);
-      goto out;
-    }
+  g_debug ("setting %s default on %s",
+           cd_profile_get_id (profile),
+           cd_device_get_id (device));
+  cd_device_make_profile_default (device,
+                                  profile,
+                                  priv->cancellable,
+                                  gcm_prefs_make_profile_default_cb,
+                                  prefs);
 out:
   if (profile != NULL)
     g_object_unref (profile);
@@ -718,16 +735,11 @@ gcm_prefs_button_assign_ok_cb (GtkWidget *widget, CcColorPanel *prefs)
     }
 
   /* make it default */
-  ret = cd_device_make_profile_default_sync (priv->current_device,
-                                             profile,
-                                             priv->cancellable,
-                                             &error);
-  if (!ret)
-    {
-      g_warning ("failed to set default: %s", error->message);
-      g_error_free (error);
-      goto out;
-    }
+  cd_device_make_profile_default (priv->current_device,
+                                  profile,
+                                  priv->cancellable,
+                                  gcm_prefs_make_profile_default_cb,
+                                  prefs);
 out:
   if (profile != NULL)
     g_object_unref (profile);
@@ -1596,8 +1608,17 @@ gcm_prefs_device_set_model_by_iter (CcColorPanel *prefs, CdDevice *device, GtkTr
       /* ignore profiles from other user accounts */
       if (!cd_profile_has_access (profile))
         {
-          g_warning ("%s is not usable by this user",
-                     cd_profile_get_filename (profile));
+          /* only print the filename if it exists */
+          if (cd_profile_get_filename (profile) != NULL)
+            {
+              g_warning ("%s is not usable by this user",
+                         cd_profile_get_filename (profile));
+            }
+          else
+            {
+              g_warning ("%s is not usable by this user",
+                         cd_profile_get_id (profile));
+            }
           goto out;
         }
 #endif
