@@ -32,20 +32,17 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <polkit/polkit.h>
-#include <dbus/dbus-glib-bindings.h>
 
 #ifdef HAVE_CHEESE
 #include <gst/gst.h>
 #endif /* HAVE_CHEESE */
 
-#include "marshal.h"
-
 #include "shell/cc-editable-entry.h"
 
 #include "um-user.h"
 #include "um-user-manager.h"
 
-#include "um-strength-bar.h"
+#include "cc-strength-bar.h"
 #include "um-editable-button.h"
 #include "um-editable-combo.h"
 
@@ -1244,13 +1241,10 @@ um_user_panel_init (UmUserPanel *self)
         GtkWidget *button;
         GtkStyleContext *context;
 
-        dbus_g_object_register_marshaller (fprintd_marshal_VOID__STRING_BOOLEAN,
-                                           G_TYPE_NONE, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_INVALID);
-
         d = self->priv = UM_USER_PANEL_PRIVATE (self);
 
         /* register types that the builder might need */
-        type = um_strength_bar_get_type ();
+        type = cc_strength_bar_get_type ();
         type = um_editable_button_get_type ();
         type = cc_editable_entry_get_type ();
         type = um_editable_combo_get_type ();
