@@ -328,6 +328,8 @@ cc_wacom_stylus_page_init (CcWacomStylusPage *self)
 			  G_CALLBACK (button_changed_cb), self);
 
 	priv->nav = cc_wacom_nav_button_new ();
+        gtk_widget_set_halign (priv->nav, GTK_ALIGN_END);
+        gtk_widget_set_margin_right (priv->nav, 10);
 	gtk_grid_attach (GTK_GRID (box), priv->nav, 0, 0, 1, 1);
 }
 
@@ -394,27 +396,27 @@ update_stylus_ui (CcWacomStylusPage *page,
 	case LAYOUT_INKING:
 		remove_buttons (page->priv);
 		remove_eraser (page->priv);
-		gtk_container_child_set (CWID ("stylus-grid"),
+		gtk_container_child_set (CWID ("stylus-controls-grid"),
 					 WID ("label-tip-feel"),
-					 "top_attach", 1, NULL);
-		gtk_container_child_set (CWID ("stylus-grid"),
+					 "top_attach", 0, NULL);
+		gtk_container_child_set (CWID ("stylus-controls-grid"),
 					 WID ("box-tip-feel"),
-					 "top_attach", 1, NULL);
+					 "top_attach", 0, NULL);
 		break;
 	case LAYOUT_AIRBRUSH:
 		remove_button (page->priv);
-		gtk_container_child_set (CWID ("stylus-grid"),
+		gtk_container_child_set (CWID ("stylus-controls-grid"),
 					 WID ("label-lower-button"),
-					 "top_attach", 2, NULL);
-		gtk_container_child_set (CWID ("stylus-grid"),
+					 "top_attach", 1, NULL);
+		gtk_container_child_set (CWID ("stylus-controls-grid"),
 					 WID ("combo-bottombutton"),
-					 "top_attach", 2, NULL);
-		gtk_container_child_set (CWID ("stylus-grid"),
+					 "top_attach", 1, NULL);
+		gtk_container_child_set (CWID ("stylus-controls-grid"),
 					 WID ("label-tip-feel"),
-					 "top_attach", 3, NULL);
-		gtk_container_child_set (CWID ("stylus-grid"),
+					 "top_attach", 2, NULL);
+		gtk_container_child_set (CWID ("stylus-controls-grid"),
 					 WID ("box-tip-feel"),
-					 "top_attach", 3, NULL);
+					 "top_attach", 2, NULL);
 	case LAYOUT_OTHER:
 		/* We already warn about it in cc_wacom_stylus_page_new () */
 		break;
@@ -486,6 +488,12 @@ cc_wacom_stylus_page_new (GsdWacomStylus *stylus,
 	return GTK_WIDGET (page);
 }
 
+GsdWacomStylus *
+cc_wacom_stylus_page_get_stylus (CcWacomStylusPage *page)
+{
+	return page->priv->stylus;
+}
+
 void
 cc_wacom_stylus_page_set_navigation (CcWacomStylusPage *page,
 				     GtkNotebook *notebook)
